@@ -9,9 +9,9 @@
 # Copyright © Semantyk 2020. All rights reserved.
 #############################################
 
-from semantyk.core.resource import Resource
-from semantyk.uuid_generator import generate_uuid
-from semantyk.namespace import RDFS, SMTK
+from core.resource import Resource
+from namespace.namespace import RDFS, SMTK
+from uuid_generator import generate_uuid
 from rdflib import Literal, URIRef
 
 class Graph(Resource):
