@@ -9,7 +9,7 @@
 # Copyright © Semantyk 2020. All rights reserved.
 #############################################
 
-from semantyk.core.model import Model
+from core.model import Model
 
 class Graph(Model):
     pass
\ No newline at end of file
